package com.ruoyi.system.service;

import com.github.pagehelper.PageInfo;
import com.ruoyi.system.domain.RmResourceGroup;
import com.ruoyi.system.domain.RmResourceRegistration;

import java.util.List;

/**
 * 资源分组Service接口
 * 
 * @author gyt
 * @date 2025-08-12
 */
public interface IRmResourceGroupService 
{
    /**
     * 查询资源分组
     * 
     * @param id 资源分组主键
     * @return 资源分组
     */
    public RmResourceGroup selectRmResourceGroupById(Long id);

    /**
     * 查询资源分组列表
     * 
     * @param rmResourceGroup 资源分组
     * @return 资源分组集合
     */
    public List<RmResourceGroup> selectRmResourceGroupList(RmResourceGroup rmResourceGroup);

    /**
     * 新增资源分组
     * 
     * @param rmResourceGroup 资源分组
     * @return 结果
     */
    public int insertRmResourceGroup(RmResourceGroup rmResourceGroup);

    /**
     * 修改资源分组
     * 
     * @param rmResourceGroup 资源分组
     * @return 结果
     */
    public int updateRmResourceGroup(RmResourceGroup rmResourceGroup);

    /**
     * 批量删除资源分组
     * 
     * @param ids 需要删除的资源分组主键集合
     * @return 结果
     */
    public int deleteRmResourceGroupByIds(Long[] ids);

    /**
     * 删除资源分组信息
     * 
     * @param id 资源分组主键
     * @return 结果
     */
    public int deleteRmResourceGroupById(Long id);

    PageInfo<RmResourceRegistration> getRegisterList(RmResourceGroup rmResourceGroup);
    List<RmResourceRegistration> getAllRegisterList(RmResourceGroup rmResourceGroup);

    String exitsResourceById(RmResourceGroup rmResourceGroup);
}
